==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/securityinsights/kotlin/inputs/GetAADDataConnectorPlainArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.securityinsights.kotlin.inputs

import com.pulumi.azurenative.securityinsights.inputs.GetAADDataConnectorPlainArgs.builder
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property dataConnectorId Connector ID
 * @property resourceGroupName The name of the resource group. The name is case insensitive.
 * @property workspaceName The name of the workspace.
 */
public data class GetAADDataConnectorPlainArgs(
    public val dataConnectorId: String,
    public val resourceGroupName: String,
    public val workspaceName: String,
) : ConvertibleToJava<com.pulumi.azurenative.securityinsights.inputs.GetAADDataConnectorPlainArgs> {
    override fun toJava(): com.pulumi.azurenative.securityinsights.inputs.GetAADDataConnectorPlainArgs =
        com.pulumi.azurenative.securityinsights.inputs.GetAADDataConnectorPlainArgs.builder()
            .dataConnectorId(dataConnectorId.let({ args0 -> args0 }))
            .resourceGroupName(resourceGroupName.let({ args0 -> args0 }))
            .workspaceName(workspaceName.let({ args0 -> args0 })).build()
}

/**
 * Builder for [GetAADDataConnectorPlainArgs].
 */
@PulumiTagMarker
public class GetAADDataConnectorPlainArgsBuilder internal constructor() {
    private var dataConnectorId: String? = null

    private var resourceGroupName: String? = null

    private var workspaceName: String? = null

    /**
     * @param value Connector ID
     */
    @JvmName("cmyxjwopmhpxqilq")
    public suspend fun dataConnectorId(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.dataConnectorId = mapped
    }

    /**
     * @param value The name of the resource group. The name is case insensitive.
     */
    @JvmName("xcoilitpsbyspyky")
    public suspend fun resourceGroupName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.resourceGroupName = mapped
    }

    /**
     * @param value The name of the workspace.
     */
    @JvmName("pvsquxequvesvmat")
    public suspend fun workspaceName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.workspaceName = mapped
    }

    internal fun build(): GetAADDataConnectorPlainArgs = GetAADDataConnectorPlainArgs(
        dataConnectorId = dataConnectorId ?: throw PulumiNullFieldException("dataConnectorId"),
        resourceGroupName = resourceGroupName ?: throw PulumiNullFieldException("resourceGroupName"),
        workspaceName = workspaceName ?: throw PulumiNullFieldException("workspaceName"),
    )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/securityinsights/kotlin/inputs/GetAADDataConnectorPlainArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.securityinsights.kotlin.inputs

import com.pulumi.azurenative.securityinsights.inputs.GetAADDataConnectorPlainArgs.builder
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property dataConnectorId Connector ID
 * @property resourceGroupName The name of the resource group. The name is case insensitive.
 * @property workspaceName The name of the workspace.
 */
public data class GetAADDataConnectorPlainArgs(
    public val dataConnectorId: String,
    public val resourceGroupName: String,
    public val workspaceName: String,
) : ConvertibleToJava<com.pulumi.azurenative.securityinsights.inputs.GetAADDataConnectorPlainArgs> {
    override fun toJava(): com.pulumi.azurenative.securityinsights.inputs.GetAADDataConnectorPlainArgs =
        com.pulumi.azurenative.securityinsights.inputs.GetAADDataConnectorPlainArgs.builder()
            .dataConnectorId(dataConnectorId.let({ args0 -> args0 }))
            .resourceGroupName(resourceGroupName.let({ args0 -> args0 }))
            .workspaceName(workspaceName.let({ args0 -> args0 })).build()
}

/**
 * Builder for [GetAADDataConnectorPlainArgs].
 */
@PulumiTagMarker
public class GetAADDataConnectorPlainArgsBuilder internal constructor() {
    private var dataConnectorId: String? = null

    private var resourceGroupName: String? = null

    private var workspaceName: String? = null

    /**
     * @param value Connector ID
     */
    @JvmName("cmpexnhlnlkyxgwo")
    public suspend fun dataConnectorId(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.dataConnectorId = mapped
    }

    /**
     * @param value The name of the resource group. The name is case insensitive.
     */
    @JvmName("jblhxuctwdjhafby")
    public suspend fun resourceGroupName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.resourceGroupName = mapped
    }

    /**
     * @param value The name of the workspace.
     */
    @JvmName("ewriovibwuarnebo")
    public suspend fun workspaceName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.workspaceName = mapped
    }

    internal fun build(): GetAADDataConnectorPlainArgs = GetAADDataConnectorPlainArgs(
        dataConnectorId = dataConnectorId ?: throw PulumiNullFieldException("dataConnectorId"),
        resourceGroupName = resourceGroupName ?: throw PulumiNullFieldException("resourceGroupName"),
        workspaceName = workspaceName ?: throw PulumiNullFieldException("workspaceName"),
    )
}
